==> link_checker-1.0.0.tar.gz: test/link_checker_test.dart <==
import 'package:link_checker/link_checker.dart';
import 'package:test/test.dart';

void main() {
  final goodLink = 'https://google.com';
  final existentHost = 'https://github.com/neelkamath/nonexistent-repository';
  final nonexistentHost = 'http://lakdjflakfasldfkjadlkfj.io';
  final allLinks = [goodLink, existentHost, nonexistentHost];

  group('link status', () {
    test('a good link',
        () async => expect(await getLinkStatus(goodLink), isNull));
    test('a bad link for a website which exists',
        () async => expect(await getLinkStatus(existentHost), isPositive));
    test("a bad link for a website which doesn't exist",
        () async => expect(await getLinkStatus(nonexistentHost), isZero));
  });

  group('links in a file', () {
    test('Markdown file', () {
      expect(
        getLinksInFile(
          'test/files/files_with_extensions/has_bad_links/regular/links.md',
        ),
        emitsInAnyOrder(allLinks),
      );
    });
    test('non-Markdown file', () {
      expect(
        getLinksInFile(
          'test/files/files_with_extensions/has_bad_links/Program.java',
        ),
        emitsInAnyOrder(allLinks),
      );
    });

    group('binaries', () {
      test('JPG', () {
        expect(
          getLinksInFile(
            'test/files/files_with_extensions/has_no_bad_links/cat.jpg',
          ),
          emitsDone,
        );
      });
      test('Keynote', () {
        expect(
          getLinksInFile(
            'test/files/files_with_extensions/has_no_bad_links/dummy.key',
          ),
          emitsDone,
        );
      });
    });
  });

  group('bad links in a file', () {
    test('when there are no bad links', () {
      expect(
        getBadLinksInFile(
          'test/files/files_with_extensions/has_no_bad_links/cat.jpg',
        ),
        emitsDone,
      );
    });
    test('when there are bad links', () {
      Matcher matchBadLinkStatus(final String link, final int statusCode) =>
          TypeMatcher<BadLinkStatus>()
            ..having((status) => status.link, 'link', link)
            ..having((status) => status.link, 'status code', statusCode);

      expect(
        getBadLinksInFile(
          'test/files/files_with_extensions/has_bad_links/regular/index.html',
        ),
        emitsInAnyOrder([
          matchBadLinkStatus(existentHost, 404),
          matchBadLinkStatus(nonexistentHost, 0)
        ]),
      );
    });
  });

  group('links in a directory', () {
    test('a specific directory', () async {
      final directory = 'test/files/files_with_extensions/has_bad_links';
      await for (final location in getLinksInDirectory(directory: directory)) {
        expect(location.path, contains(directory));
      }
    });
    test('nonrecursively', () async {
      final links = <String>[];
      await for (final location
          in getLinksInDirectory(directory: 'test/files', recursive: false)) {
        expect(location.path, contains('test/files/Procfile'));
        links.add(location.link);
      }
      expect(links, allLinks);
    });
    test('blacklisted files', () {
      Matcher matchLinkLocation(final String path, final String link) =>
          TypeMatcher<LinkLocation>()
            ..having((location) => location.path, 'path', path)
            ..having((location) => location.link, 'link', link);

      final directory = 'test/files/files_with_extensions/has_bad_links';
      expect(
        getLinksInDirectory(directory: 'test/files', blacklistedFiles: [
          'test/files/Procfile',
          'test/files/files_with_extensions/has_bad_links/regular/index.html'
        ]),
        emitsInAnyOrder([
          matchLinkLocation('$directory/programs/Program.java', goodLink),
          matchLinkLocation('$directory/programs/Program.java', existentHost),
          matchLinkLocation(
              '$directory/programs/Program.java', nonexistentHost),
          matchLinkLocation('$directory/regular/links.md', goodLink),
          matchLinkLocation('$directory/regular/links.md', existentHost),
          matchLinkLocation('$directory/regular/links.md', nonexistentHost),
        ]),
      );
    });
    test('blacklisted directories', () {
      final directory = 'test/files';
      expect(
          getLinksInDirectory(
            directory: directory,
            blacklistedDirectories: [BlacklistedDirectory(directory)],
          ),
          emitsDone);
    });
  });

  group('bad links in a directory', () {
    Matcher matchBadLink(
            final String path, final String link, final int statusCode) =>
        TypeMatcher<BadLink>()
          ..having((link) => link.path, 'path', path)
          ..having((link) => link.link, 'link', link)
          ..having((link) => link.statusCode, 'status code', statusCode);

    test('a specified directory', () {
      final directory = 'test/files/files_with_extensions/has_bad_links';
      expect(
          getBadLinksInDirectory(directory: directory),
          emitsInAnyOrder([
            matchBadLink('$directory/Program.java', nonexistentHost, 0),
            matchBadLink('$directory/Program.java', existentHost, 404),
            matchBadLink('$directory/regular/index.html', nonexistentHost, 0),
            matchBadLink('$directory/regular/index.html', existentHost, 404),
            matchBadLink('$directory/regular/links.md', nonexistentHost, 0),
            matchBadLink('$directory/regular/links.md', existentHost, 404)
          ]));
    });
    test('nonrecursively', () {
      final directory = 'test/files';
      expect(
          getBadLinksInDirectory(directory: directory, recursive: false),
          emitsInAnyOrder([
            matchBadLink('$directory/Procfile', existentHost, 404),
            matchBadLink('$directory/Procfile', nonexistentHost, 0)
          ]));
    });
    test('blacklisted files', () {
      final directory = 'test/files/files_with_extensions/has_bad_links';
      expect(
          getBadLinksInDirectory(directory: directory, blacklistedFiles: [
            '$directory/regular/index.html',
            '$directory/Program.java'
          ]),
          emitsInAnyOrder([
            matchBadLink('$directory/regular/links.md', existentHost, 404),
            matchBadLink('$directory/regular/links.md', nonexistentHost, 0)
          ]));
    });
    test('blacklisted files and blacklisted directories', () {
      final directory = 'test/files/files_with_extensions/has_bad_links';
      expect(
          getBadLinksInDirectory(directory: 'test/files', blacklistedFiles: [
            'test/files/Procfile'
          ], blacklistedDirectories: [
            BlacklistedDirectory('$directory/regular')
          ]),
          emitsInAnyOrder([
            matchBadLink('$directory/Program.java', existentHost, 404),
            matchBadLink('$directory/Program.java', nonexistentHost, 0)
          ]));
    });
  });
}

==> link_checker-1.1.1.tar.gz: test/link_checker_test.dart <==
import 'dart:io';

import 'package:link_checker/link_checker.dart';
import 'package:test/test.dart';

void main() {
  test('links', () async {
    final links = <BadLink>[];
    try {
      await for (final link in getBadLinksInDirectory(blacklistedFiles: [
        'pubspec.lock'
      ], blacklistedDirectories: [
        BlacklistedDirectory('doc'),
        BlacklistedDirectory('test'),
        BlacklistedDirectory('example')
      ])) {
        links.add(link);
      }
    } on HandshakeException {
      // This test is being run on a device not having a valid SSL certificate.
    }

    expect(links, isEmpty);
  });

  final goodLink = 'https://google.com';
  final existentHost = 'https://github.com/neelkamath/nonexistent-repository';
  final nonexistentHost = 'http://lakdjflakfasldfkjadlkfj.io';
  final allLinks = [goodLink, existentHost, nonexistentHost];

  group('link status', () {
    test('a good link',
        () async => expect(await getLinkStatus(goodLink), isNull));
    test('a bad link for a website which exists',
        () async => expect(await getLinkStatus(existentHost), isPositive));
    test("a bad link for a website which doesn't exist",
        () async => expect(await getLinkStatus(nonexistentHost), isZero));
  });

  group('links in a file', () {
    test('Markdown file', () {
      expect(
        getLinksInFile(
          'test/files/files_with_extensions/has_bad_links/regular/links.md',
        ),
        emitsInAnyOrder(allLinks),
      );
    });
    test('non-Markdown file', () {
      expect(
        getLinksInFile(
          'test/files/files_with_extensions/has_bad_links/Program.java',
        ),
        emitsInAnyOrder(allLinks),
      );
    });

    group('binaries', () {
      test('JPG', () {
        expect(
          getLinksInFile(
            'test/files/files_with_extensions/has_no_bad_links/cat.jpg',
          ),
          emitsDone,
        );
      });
      test('Keynote', () {
        expect(
          getLinksInFile(
            'test/files/files_with_extensions/has_no_bad_links/dummy.key',
          ),
          emitsDone,
        );
      });
    });
  });

  group('bad links in a file', () {
    test('when there are no bad links', () {
      expect(
        getBadLinksInFile(
          'test/files/files_with_extensions/has_no_bad_links/cat.jpg',
        ),
        emitsDone,
      );
    });
    test('when there are bad links', () {
      Matcher matchBadLinkStatus(final String link, final int statusCode) =>
          TypeMatcher<BadLinkStatus>()
              .having((status) => status.link, 'link', link)
              .having((status) => status.statusCode, 'status code', statusCode);

      expect(
        getBadLinksInFile(
          'test/files/files_with_extensions/has_bad_links/regular/index.html',
        ),
        emitsInAnyOrder([
          matchBadLinkStatus(existentHost, 404),
          matchBadLinkStatus(nonexistentHost, 0)
        ]),
      );
    });
  });

  group('links in a directory', () {
    test('a specific directory', () async {
      final directory = 'test/files/files_with_extensions/has_bad_links';
      await for (final location in getLinksInDirectory(directory: directory)) {
        expect(location.path, contains(directory));
      }
    });
    test('nonrecursively', () async {
      final links = <String>[];
      await for (final location
          in getLinksInDirectory(directory: 'test/files', recursive: false)) {
        expect(location.path, contains('test/files/Procfile'));
        links.add(location.link);
      }
      expect(links, allLinks);
    });
    test('blacklisted files', () {
      Matcher matchLinkLocation(final String path, final String link) =>
          TypeMatcher<LinkLocation>()
              .having((location) => location.path, 'path', path)
              .having((location) => location.link, 'link', link);

      final directory = 'test/files/files_with_extensions/has_bad_links';
      expect(
        getLinksInDirectory(directory: 'test/files', blacklistedFiles: [
          'test/files/Procfile',
          'test/files/files_with_extensions/has_bad_links/regular/index.html'
        ]),
        emitsInAnyOrder([
          matchLinkLocation('$directory/Program.java', goodLink),
          matchLinkLocation('$directory/Program.java', existentHost),
          matchLinkLocation('$directory/Program.java', nonexistentHost),
          matchLinkLocation('$directory/regular/links.md', goodLink),
          matchLinkLocation('$directory/regular/links.md', existentHost),
          matchLinkLocation('$directory/regular/links.md', nonexistentHost),
        ]),
      );
    });
    test('blacklisted directories', () {
      final directory = 'test/files';
      expect(
          getLinksInDirectory(
            directory: directory,
            blacklistedDirectories: [BlacklistedDirectory(directory)],
          ),
          emitsDone);
    });
  });

  group('bad links in a directory', () {
    Matcher matchBadLink(
            final String path, final String link, final int statusCode) =>
        TypeMatcher<BadLink>()
            .having((link) => link.path, 'path', path)
            .having((link) => link.link, 'link', link)
            .having((link) => link.statusCode, 'status code', statusCode);

    test('a specified directory', () {
      final directory = 'test/files/files_with_extensions/has_bad_links';
      expect(
          getBadLinksInDirectory(directory: directory),
          emitsInAnyOrder([
            matchBadLink('$directory/Program.java', nonexistentHost, 0),
            matchBadLink('$directory/Program.java', existentHost, 404),
            matchBadLink('$directory/regular/index.html', nonexistentHost, 0),
            matchBadLink('$directory/regular/index.html', existentHost, 404),
            matchBadLink('$directory/regular/links.md', nonexistentHost, 0),
            matchBadLink('$directory/regular/links.md', existentHost, 404)
          ]));
    });
    test('nonrecursively', () {
      final directory = 'test/files';
      expect(
          getBadLinksInDirectory(directory: directory, recursive: false),
          emitsInAnyOrder([
            matchBadLink('$directory/Procfile', existentHost, 404),
            matchBadLink('$directory/Procfile', nonexistentHost, 0)
          ]));
    });
    test('blacklisted files', () {
      final directory = 'test/files/files_with_extensions/has_bad_links';
      expect(
          getBadLinksInDirectory(directory: directory, blacklistedFiles: [
            '$directory/regular/index.html',
            '$directory/Program.java'
          ]),
          emitsInAnyOrder([
            matchBadLink('$directory/regular/links.md', existentHost, 404),
            matchBadLink('$directory/regular/links.md', nonexistentHost, 0)
          ]));
    });
    test('blacklisted files and blacklisted directories', () {
      final directory = 'test/files/files_with_extensions/has_bad_links';
      expect(
          getBadLinksInDirectory(directory: 'test/files', blacklistedFiles: [
            'test/files/Procfile'
          ], blacklistedDirectories: [
            BlacklistedDirectory('$directory/regular')
          ]),
          emitsInAnyOrder([
            matchBadLink('$directory/Program.java', existentHost, 404),
            matchBadLink('$directory/Program.java', nonexistentHost, 0)
          ]));
    });
  });
}
